Class: Google::Apis::ComposerV1::EnvironmentConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComposerV1::EnvironmentConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/composer_v1/classes.rb,
lib/google/apis/composer_v1/representations.rb,
lib/google/apis/composer_v1/representations.rb
Overview
Configuration information for an environment.
Instance Attribute Summary collapse
-
#airflow_byoid_uri ⇒ String
Output only.
-
#airflow_uri ⇒ String
Output only.
-
#dag_gcs_prefix ⇒ String
Output only.
-
#data_retention_config ⇒ Google::Apis::ComposerV1::DataRetentionConfig
The configuration setting for Airflow database data retention mechanism.
-
#database_config ⇒ Google::Apis::ComposerV1::DatabaseConfig
The configuration of Cloud SQL instance that is used by the Apache Airflow software.
-
#encryption_config ⇒ Google::Apis::ComposerV1::EncryptionConfig
The encryption options for the Cloud Composer environment and its dependencies.
-
#environment_size ⇒ String
Optional.
-
#gke_cluster ⇒ String
Output only.
-
#maintenance_window ⇒ Google::Apis::ComposerV1::MaintenanceWindow
The configuration settings for Cloud Composer maintenance window.
-
#master_authorized_networks_config ⇒ Google::Apis::ComposerV1::MasterAuthorizedNetworksConfig
Configuration options for the master authorized networks feature.
-
#node_config ⇒ Google::Apis::ComposerV1::NodeConfig
The configuration information for the Kubernetes Engine nodes running the Apache Airflow software.
-
#node_count ⇒ Fixnum
The number of nodes in the Kubernetes Engine cluster that will be used to run this environment.
-
#private_environment_config ⇒ Google::Apis::ComposerV1::PrivateEnvironmentConfig
The configuration information for configuring a Private IP Cloud Composer environment.
-
#recovery_config ⇒ Google::Apis::ComposerV1::RecoveryConfig
The Recovery settings of an environment.
-
#resilience_mode ⇒ String
Optional.
-
#software_config ⇒ Google::Apis::ComposerV1::SoftwareConfig
Specifies the selection and configuration of software inside the environment.
-
#web_server_config ⇒ Google::Apis::ComposerV1::WebServerConfig
The configuration settings for the Airflow web server App Engine instance.
-
#web_server_network_access_control ⇒ Google::Apis::ComposerV1::WebServerNetworkAccessControl
Network-level access control policy for the Airflow web server.
-
#workloads_config ⇒ Google::Apis::ComposerV1::WorkloadsConfig
The Kubernetes workloads configuration for GKE cluster associated with the Cloud Composer environment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EnvironmentConfig
constructor
A new instance of EnvironmentConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EnvironmentConfig
Returns a new instance of EnvironmentConfig.
718 719 720 |
# File 'lib/google/apis/composer_v1/classes.rb', line 718 def initialize(**args) update!(**args) end |
Instance Attribute Details
#airflow_byoid_uri ⇒ String
Output only. The 'bring your own identity' variant of the URI of the Apache
Airflow Web UI hosted within this environment, to be accessed with external
identities using workforce identity federation (see Access environments with
workforce identity federation).
Corresponds to the JSON property airflowByoidUri
599 600 601 |
# File 'lib/google/apis/composer_v1/classes.rb', line 599 def airflow_byoid_uri @airflow_byoid_uri end |
#airflow_uri ⇒ String
Output only. The URI of the Apache Airflow Web UI hosted within this
environment (see Airflow web interface).
Corresponds to the JSON property airflowUri
606 607 608 |
# File 'lib/google/apis/composer_v1/classes.rb', line 606 def airflow_uri @airflow_uri end |
#dag_gcs_prefix ⇒ String
Output only. The Cloud Storage prefix of the DAGs for this environment.
Although Cloud Storage objects reside in a flat namespace, a hierarchical file
tree can be simulated using "/"-delimited object name prefixes. DAG objects
for this environment reside in a simulated directory with the given prefix.
Corresponds to the JSON property dagGcsPrefix
614 615 616 |
# File 'lib/google/apis/composer_v1/classes.rb', line 614 def dag_gcs_prefix @dag_gcs_prefix end |
#data_retention_config ⇒ Google::Apis::ComposerV1::DataRetentionConfig
The configuration setting for Airflow database data retention mechanism.
Corresponds to the JSON property dataRetentionConfig
619 620 621 |
# File 'lib/google/apis/composer_v1/classes.rb', line 619 def data_retention_config @data_retention_config end |
#database_config ⇒ Google::Apis::ComposerV1::DatabaseConfig
The configuration of Cloud SQL instance that is used by the Apache Airflow
software.
Corresponds to the JSON property databaseConfig
625 626 627 |
# File 'lib/google/apis/composer_v1/classes.rb', line 625 def database_config @database_config end |
#encryption_config ⇒ Google::Apis::ComposerV1::EncryptionConfig
The encryption options for the Cloud Composer environment and its dependencies.
Supported for Cloud Composer environments in versions composer-1..-airflow-.
*..
Corresponds to the JSON property encryptionConfig
632 633 634 |
# File 'lib/google/apis/composer_v1/classes.rb', line 632 def encryption_config @encryption_config end |
#environment_size ⇒ String
Optional. The size of the Cloud Composer environment. This field is supported
for Cloud Composer environments in versions composer-2..-airflow-..* and
newer.
Corresponds to the JSON property environmentSize
639 640 641 |
# File 'lib/google/apis/composer_v1/classes.rb', line 639 def environment_size @environment_size end |
#gke_cluster ⇒ String
Output only. The Kubernetes Engine cluster used to run this environment.
Corresponds to the JSON property gkeCluster
644 645 646 |
# File 'lib/google/apis/composer_v1/classes.rb', line 644 def gke_cluster @gke_cluster end |
#maintenance_window ⇒ Google::Apis::ComposerV1::MaintenanceWindow
The configuration settings for Cloud Composer maintenance window. The
following example: ` "startTime":"2019-08-01T01:00:00Z" "endTime":"2019-08-
01T07:00:00Z" "recurrence":"FREQ=WEEKLY;BYDAY=TU,WE" ` would define a
maintenance window between 01 and 07 hours UTC during each Tuesday and
Wednesday.
Corresponds to the JSON property maintenanceWindow
653 654 655 |
# File 'lib/google/apis/composer_v1/classes.rb', line 653 def maintenance_window @maintenance_window end |
#master_authorized_networks_config ⇒ Google::Apis::ComposerV1::MasterAuthorizedNetworksConfig
Configuration options for the master authorized networks feature. Enabled
master authorized networks will disallow all external traffic to access
Kubernetes master through HTTPS except traffic from the given CIDR blocks,
Google Compute Engine Public IPs and Google Prod IPs.
Corresponds to the JSON property masterAuthorizedNetworksConfig
661 662 663 |
# File 'lib/google/apis/composer_v1/classes.rb', line 661 def @master_authorized_networks_config end |
#node_config ⇒ Google::Apis::ComposerV1::NodeConfig
The configuration information for the Kubernetes Engine nodes running the
Apache Airflow software.
Corresponds to the JSON property nodeConfig
667 668 669 |
# File 'lib/google/apis/composer_v1/classes.rb', line 667 def node_config @node_config end |
#node_count ⇒ Fixnum
The number of nodes in the Kubernetes Engine cluster that will be used to run
this environment. This field is supported for Cloud Composer environments in
versions composer-1..-airflow-..*.
Corresponds to the JSON property nodeCount
674 675 676 |
# File 'lib/google/apis/composer_v1/classes.rb', line 674 def node_count @node_count end |
#private_environment_config ⇒ Google::Apis::ComposerV1::PrivateEnvironmentConfig
The configuration information for configuring a Private IP Cloud Composer
environment.
Corresponds to the JSON property privateEnvironmentConfig
680 681 682 |
# File 'lib/google/apis/composer_v1/classes.rb', line 680 def private_environment_config @private_environment_config end |
#recovery_config ⇒ Google::Apis::ComposerV1::RecoveryConfig
The Recovery settings of an environment.
Corresponds to the JSON property recoveryConfig
685 686 687 |
# File 'lib/google/apis/composer_v1/classes.rb', line 685 def recovery_config @recovery_config end |
#resilience_mode ⇒ String
Optional. Resilience mode of the Cloud Composer Environment. This field is
supported for Cloud Composer environments in versions composer-2.2.0-airflow-.
*. and newer.
Corresponds to the JSON property resilienceMode
692 693 694 |
# File 'lib/google/apis/composer_v1/classes.rb', line 692 def resilience_mode @resilience_mode end |
#software_config ⇒ Google::Apis::ComposerV1::SoftwareConfig
Specifies the selection and configuration of software inside the environment.
Corresponds to the JSON property softwareConfig
697 698 699 |
# File 'lib/google/apis/composer_v1/classes.rb', line 697 def software_config @software_config end |
#web_server_config ⇒ Google::Apis::ComposerV1::WebServerConfig
The configuration settings for the Airflow web server App Engine instance.
Supported for Cloud Composer environments in versions composer-1..-airflow-.
*.
Corresponds to the JSON property webServerConfig
704 705 706 |
# File 'lib/google/apis/composer_v1/classes.rb', line 704 def web_server_config @web_server_config end |
#web_server_network_access_control ⇒ Google::Apis::ComposerV1::WebServerNetworkAccessControl
Network-level access control policy for the Airflow web server.
Corresponds to the JSON property webServerNetworkAccessControl
709 710 711 |
# File 'lib/google/apis/composer_v1/classes.rb', line 709 def web_server_network_access_control @web_server_network_access_control end |
#workloads_config ⇒ Google::Apis::ComposerV1::WorkloadsConfig
The Kubernetes workloads configuration for GKE cluster associated with the
Cloud Composer environment. Supported for Cloud Composer environments in
versions composer-2..-airflow-..* and newer.
Corresponds to the JSON property workloadsConfig
716 717 718 |
# File 'lib/google/apis/composer_v1/classes.rb', line 716 def workloads_config @workloads_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 |
# File 'lib/google/apis/composer_v1/classes.rb', line 723 def update!(**args) @airflow_byoid_uri = args[:airflow_byoid_uri] if args.key?(:airflow_byoid_uri) @airflow_uri = args[:airflow_uri] if args.key?(:airflow_uri) @dag_gcs_prefix = args[:dag_gcs_prefix] if args.key?(:dag_gcs_prefix) @data_retention_config = args[:data_retention_config] if args.key?(:data_retention_config) @database_config = args[:database_config] if args.key?(:database_config) @encryption_config = args[:encryption_config] if args.key?(:encryption_config) @environment_size = args[:environment_size] if args.key?(:environment_size) @gke_cluster = args[:gke_cluster] if args.key?(:gke_cluster) @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window) @master_authorized_networks_config = args[:master_authorized_networks_config] if args.key?(:master_authorized_networks_config) @node_config = args[:node_config] if args.key?(:node_config) @node_count = args[:node_count] if args.key?(:node_count) @private_environment_config = args[:private_environment_config] if args.key?(:private_environment_config) @recovery_config = args[:recovery_config] if args.key?(:recovery_config) @resilience_mode = args[:resilience_mode] if args.key?(:resilience_mode) @software_config = args[:software_config] if args.key?(:software_config) @web_server_config = args[:web_server_config] if args.key?(:web_server_config) @web_server_network_access_control = args[:web_server_network_access_control] if args.key?(:web_server_network_access_control) @workloads_config = args[:workloads_config] if args.key?(:workloads_config) end |