Class: Google::Apis::ComposerV1::ExecuteAirflowCommandResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComposerV1::ExecuteAirflowCommandResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/composer_v1/classes.rb,
lib/google/apis/composer_v1/representations.rb,
lib/google/apis/composer_v1/representations.rb
Overview
Response to ExecuteAirflowCommandRequest.
Instance Attribute Summary collapse
-
#error ⇒ String
Error message.
-
#execution_id ⇒ String
The unique ID of the command execution for polling.
-
#pod ⇒ String
The name of the pod where the command is executed.
-
#pod_namespace ⇒ String
The namespace of the pod where the command is executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExecuteAirflowCommandResponse
constructor
A new instance of ExecuteAirflowCommandResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExecuteAirflowCommandResponse
Returns a new instance of ExecuteAirflowCommandResponse.
803 804 805 |
# File 'lib/google/apis/composer_v1/classes.rb', line 803 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ String
Error message. Empty if there was no error.
Corresponds to the JSON property error
786 787 788 |
# File 'lib/google/apis/composer_v1/classes.rb', line 786 def error @error end |
#execution_id ⇒ String
The unique ID of the command execution for polling.
Corresponds to the JSON property executionId
791 792 793 |
# File 'lib/google/apis/composer_v1/classes.rb', line 791 def execution_id @execution_id end |
#pod ⇒ String
The name of the pod where the command is executed.
Corresponds to the JSON property pod
796 797 798 |
# File 'lib/google/apis/composer_v1/classes.rb', line 796 def pod @pod end |
#pod_namespace ⇒ String
The namespace of the pod where the command is executed.
Corresponds to the JSON property podNamespace
801 802 803 |
# File 'lib/google/apis/composer_v1/classes.rb', line 801 def pod_namespace @pod_namespace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
808 809 810 811 812 813 |
# File 'lib/google/apis/composer_v1/classes.rb', line 808 def update!(**args) @error = args[:error] if args.key?(:error) @execution_id = args[:execution_id] if args.key?(:execution_id) @pod = args[:pod] if args.key?(:pod) @pod_namespace = args[:pod_namespace] if args.key?(:pod_namespace) end |