Class: Google::Apis::ComposerV1::FetchDatabasePropertiesResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/composer_v1/classes.rb,
lib/google/apis/composer_v1/representations.rb,
lib/google/apis/composer_v1/representations.rb

Overview

Response for FetchDatabasePropertiesRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FetchDatabasePropertiesResponse

Returns a new instance of FetchDatabasePropertiesResponse.



864
865
866
# File 'lib/google/apis/composer_v1/classes.rb', line 864

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#is_failover_replica_availableBoolean Also known as: is_failover_replica_available?

The availability status of the failover replica. A false status indicates that the failover replica is out of sync. The primary instance can only fail over to the failover replica when the status is true. Corresponds to the JSON property isFailoverReplicaAvailable

Returns:

  • (Boolean)


850
851
852
# File 'lib/google/apis/composer_v1/classes.rb', line 850

def is_failover_replica_available
  @is_failover_replica_available
end

#primary_gce_zoneString

The Compute Engine zone that the instance is currently serving from. Corresponds to the JSON property primaryGceZone

Returns:

  • (String)


856
857
858
# File 'lib/google/apis/composer_v1/classes.rb', line 856

def primary_gce_zone
  @primary_gce_zone
end

#secondary_gce_zoneString

The Compute Engine zone that the failover instance is currently serving from for a regional Cloud SQL instance. Corresponds to the JSON property secondaryGceZone

Returns:

  • (String)


862
863
864
# File 'lib/google/apis/composer_v1/classes.rb', line 862

def secondary_gce_zone
  @secondary_gce_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



869
870
871
872
873
# File 'lib/google/apis/composer_v1/classes.rb', line 869

def update!(**args)
  @is_failover_replica_available = args[:is_failover_replica_available] if args.key?(:is_failover_replica_available)
  @primary_gce_zone = args[:primary_gce_zone] if args.key?(:primary_gce_zone)
  @secondary_gce_zone = args[:secondary_gce_zone] if args.key?(:secondary_gce_zone)
end