Class: Google::Apis::ComposerV1::PollAirflowCommandRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComposerV1::PollAirflowCommandRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/composer_v1/classes.rb,
lib/google/apis/composer_v1/representations.rb,
lib/google/apis/composer_v1/representations.rb
Overview
Poll Airflow Command request.
Instance Attribute Summary collapse
-
#execution_id ⇒ String
The unique ID of the command execution.
-
#next_line_number ⇒ Fixnum
Line number from which new logs should be fetched.
-
#pod ⇒ String
The name of the pod where the command is executed.
-
#pod_namespace ⇒ String
The namespace of the pod where the command is executed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PollAirflowCommandRequest
constructor
A new instance of PollAirflowCommandRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PollAirflowCommandRequest
Returns a new instance of PollAirflowCommandRequest.
1634 1635 1636 |
# File 'lib/google/apis/composer_v1/classes.rb', line 1634 def initialize(**args) update!(**args) end |
Instance Attribute Details
#execution_id ⇒ String
The unique ID of the command execution.
Corresponds to the JSON property executionId
1617 1618 1619 |
# File 'lib/google/apis/composer_v1/classes.rb', line 1617 def execution_id @execution_id end |
#next_line_number ⇒ Fixnum
Line number from which new logs should be fetched.
Corresponds to the JSON property nextLineNumber
1622 1623 1624 |
# File 'lib/google/apis/composer_v1/classes.rb', line 1622 def next_line_number @next_line_number end |
#pod ⇒ String
The name of the pod where the command is executed.
Corresponds to the JSON property pod
1627 1628 1629 |
# File 'lib/google/apis/composer_v1/classes.rb', line 1627 def pod @pod end |
#pod_namespace ⇒ String
The namespace of the pod where the command is executed.
Corresponds to the JSON property podNamespace
1632 1633 1634 |
# File 'lib/google/apis/composer_v1/classes.rb', line 1632 def pod_namespace @pod_namespace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1639 1640 1641 1642 1643 1644 |
# File 'lib/google/apis/composer_v1/classes.rb', line 1639 def update!(**args) @execution_id = args[:execution_id] if args.key?(:execution_id) @next_line_number = args[:next_line_number] if args.key?(:next_line_number) @pod = args[:pod] if args.key?(:pod) @pod_namespace = args[:pod_namespace] if args.key?(:pod_namespace) end |