Class: Google::Apis::ComposerV1::ScheduledSnapshotsConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/composer_v1/classes.rb,
lib/google/apis/composer_v1/representations.rb,
lib/google/apis/composer_v1/representations.rb

Overview

The configuration for scheduled snapshot creation mechanism.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ScheduledSnapshotsConfig

Returns a new instance of ScheduledSnapshotsConfig.



1937
1938
1939
# File 'lib/google/apis/composer_v1/classes.rb', line 1937

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Optional. Whether scheduled snapshots creation is enabled. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


1915
1916
1917
# File 'lib/google/apis/composer_v1/classes.rb', line 1915

def enabled
  @enabled
end

#snapshot_creation_scheduleString

Optional. The cron expression representing the time when snapshots creation mechanism runs. This field is subject to additional validation around frequency of execution. Corresponds to the JSON property snapshotCreationSchedule

Returns:

  • (String)


1923
1924
1925
# File 'lib/google/apis/composer_v1/classes.rb', line 1923

def snapshot_creation_schedule
  @snapshot_creation_schedule
end

#snapshot_locationString

Optional. The Cloud Storage location for storing automatically created snapshots. Corresponds to the JSON property snapshotLocation

Returns:

  • (String)


1929
1930
1931
# File 'lib/google/apis/composer_v1/classes.rb', line 1929

def snapshot_location
  @snapshot_location
end

#time_zoneString

Optional. Time zone that sets the context to interpret snapshot_creation_schedule. Corresponds to the JSON property timeZone

Returns:

  • (String)


1935
1936
1937
# File 'lib/google/apis/composer_v1/classes.rb', line 1935

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1942
1943
1944
1945
1946
1947
# File 'lib/google/apis/composer_v1/classes.rb', line 1942

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @snapshot_creation_schedule = args[:snapshot_creation_schedule] if args.key?(:snapshot_creation_schedule)
  @snapshot_location = args[:snapshot_location] if args.key?(:snapshot_location)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end