Class: Google::Apis::ComposerV1::NetworkingConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComposerV1::NetworkingConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/composer_v1/classes.rb,
lib/google/apis/composer_v1/representations.rb,
lib/google/apis/composer_v1/representations.rb
Overview
Configuration options for networking connections in the Composer 2 environment.
Instance Attribute Summary collapse
-
#connection_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkingConfig
constructor
A new instance of NetworkingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkingConfig
Returns a new instance of NetworkingConfig.
1334 1335 1336 |
# File 'lib/google/apis/composer_v1/classes.rb', line 1334 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection_type ⇒ String
Optional. Indicates the user requested specific connection type between Tenant
and Customer projects. You cannot set networking connection type in public IP
environment.
Corresponds to the JSON property connectionType
1332 1333 1334 |
# File 'lib/google/apis/composer_v1/classes.rb', line 1332 def connection_type @connection_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1339 1340 1341 |
# File 'lib/google/apis/composer_v1/classes.rb', line 1339 def update!(**args) @connection_type = args[:connection_type] if args.key?(:connection_type) end |